pub struct MotionDetector { /* private fields */ }Expand description
Core motion detection engine
Implementations
Sourceimpl MotionDetector
impl MotionDetector
Sourcepub fn new(config: MotionConfig) -> Result<Self, MotionError>
pub fn new(config: MotionConfig) -> Result<Self, MotionError>
Create a new motion detector with the given configuration
Sourcepub fn feed_frame(
&mut self,
frame: &GrayImage,
) -> Result<Option<MotionEvent>, MotionError>
pub fn feed_frame( &mut self, frame: &GrayImage, ) -> Result<Option<MotionEvent>, MotionError>
Feed a frame to the detector and check for motion
Sourcepub fn stats(&self) -> DetectorStats
pub fn stats(&self) -> DetectorStats
Get detector statistics